@@ -7,7 +7,7 @@ from scientific_survey.models import Response
 
 class ConfirmView(TemplateView):
 
-    template_name = "survey/confirm.html"
+    template_name = "scientific_survey/confirm.html"
 
     def get_context_data(self, **kwargs):
         context = super(ConfirmView, self).get_context_data(**kwargs)
