@@ -8,7 +8,7 @@ from scientific_survey.models import Survey
 
 class SurveyCompleted(TemplateView):
 
-    template_name = "survey/completed.html"
+    template_name = "scientific_survey/completed.html"
 
     def get_context_data(self, **kwargs):
         context = {}
